![Banner](https://rawcdn.githack.com/rlaPHOENiX/pydvdcss/dfea6bed42cf13cb9d5839ddc1c54f4efbc5ec5e/banner.png)

* * *

[![Docs](https://readthedocs.org/projects/pip/badge/)](https://pydvdcss.readthedocs.io)
![Python version tests](https://github.com/rlaPHOENiX/pydvdcss/workflows/Build/badge.svg?branch=master)
![Python versions](https://img.shields.io/pypi/pyversions/pydvdcss)
[![PyPI version](https://img.shields.io/pypi/v/pydvdcss)](https://pypi.python.org/pypi/pydvdcss)
[![GPLv3 license](https://img.shields.io/badge/license-GPLv3-blue)](https://github.com/rlaPHOENiX/pydvdcss/blob/master/LICENSE)
[![PyPI status](https://img.shields.io/pypi/status/pydvdcss)](https://pypi.python.org/pypi/pydvdcss)
[![GitHub issues](https://img.shields.io/github/issues/rlaPHOENiX/pydvdcss)](https://github.com/rlaPHOENiX/pydvdcss/issues)
[![DeepSource issues](https://deepsource.io/gh/rlaPHOENiX/pydvdcss.svg/?label=active+issues)](https://deepsource.io/gh/rlaPHOENiX/pydvdcss/?ref=repository-badge)
[![Contributors](https://img.shields.io/github/contributors/rlaPHOENiX/pydvdcss)](https://github.com/rlaPHOENiX/pydvdcss/graphs/contributors)

**pydvdcss** is a python wrapper for VideoLAN's [libdvdcss].

[libdvdcss] is a simple library designed for accessing DVDs like a block device without having to bother about the
decryption.

  [libdvdcss]: <https://www.videolan.org/developers/libdvdcss.html>

* * *

## [DOCS](https://pydvdcss.readthedocs.io)

## [INSTALLATION](https://pydvdcss.readthedocs.io/en/latest/installation.html)

## [TO-DO](https://pydvdcss.readthedocs.io/en/latest/todo.html)

* * *

## [PHOENiX](https://github.com/rlaPHOENiX)

## [LICENSE (GPLv3)](https://github.com/rlaPHOENiX/pydvdcss/blob/master/LICENSE)

## [CONTRIBUTORS](https://github.com/rlaPHOENiX/pydvdcss/graphs/contributors)
